@@ -1,6 +1,6 @@
 package Net::Kubernetes::Namespace;
 # ABSTRACT: Provides access to kubernetes respources within a single namespace.
-$Net::Kubernetes::Namespace::VERSION = '1.03';
+$Net::Kubernetes::Namespace::VERSION = '1.04';
 use Moose;
 use MooseX::Aliases;
 use syntax 'try';
@@ -8,7 +8,7 @@ use syntax 'try';
 has namespace => (
 	is       => 'ro',
 	isa      => 'Str',
-	required => 0,
+	required => 1,
 );
 
 has _namespace_data => (
@@ -26,30 +26,43 @@ with 'Net::Kubernetes::Role::SecretBuilder';
 
 
 sub get_secret {
-	my($self, $name) = @_;
+	my ($self, $name) = @_;
 	Net::Kubernetes::Exception->throw(message=>"Missing required parameter 'name'") if(! defined $name || ! length $name);
-	return $self->get_resource_by_name($name, 'secrets');
+	return $self->get_resource_by_name($name, 'secret');
 }
 
 sub get_pod {
-	my($self, $name) = @_;
+	my ($self, $name) = @_;
 	Net::Kubernetes::Exception->throw(message=>"Missing required parameter 'name'") if(! defined $name || ! length $name);
-	return $self->get_resource_by_name($name, 'pods');
+	return $self->get_resource_by_name($name, 'pod');
 }
 
 sub get_service {
-	my($self, $name) = @_;
+	my ($self, $name) = @_;
 	Net::Kubernetes::Exception->throw(message=>"Missing required parameter 'name'") if(! defined $name || ! length $name);
-	return $self->get_resource_by_name($name, 'services');
+	return $self->get_resource_by_name($name, 'service');
 }
 
 sub get_replication_controller {
-	my($self, $name) = @_;
+	my ($self, $name) = @_;
 	Net::Kubernetes::Exception->throw(message=>"Missing required parameter 'name'") if(! defined $name || ! length $name);
-	return $self->get_resource_by_name($name, 'replicationcontrollers');
+	return $self->get_resource_by_name($name, 'replicationcontroller');
 }
 alias get_rc => 'get_replication_controller';
 
+sub get_deployment {
+	my ($self, $name) = @_;
+	Net::Kubernetes::Exception->throw(message=>"Missing required parameter 'name'") if(! defined $name || ! length $name);
+	return $self->get_resource_by_name($name, 'deployment');
+}
+
+sub get_replica_set {
+	my($self, $name) = @_;
+	Net::Kubernetes::Exception->throw(message=>"Missing required parameter 'name'") if(! defined $name || ! length $name);
+	return $self->get_resource_by_name($name, 'replicaset');
+}
+alias get_rs => 'get_replica_set';
+
 return 42;
 
 __END__
@@ -64,7 +77,7 @@ Net::Kubernetes::Namespace - Provides access to kubernetes respources within a s
 
 =head1 VERSION
 
-version 1.03
+version 1.04
 
 =head1 METHODS
 
@@ -76,13 +89,15 @@ version 1.03
 
 =head2 $ns->get_secret('my-secret-name')
 
+=head2 $ns->get_deployment('my-deployment-name')
+
 =head1 AUTHOR
 
 Dave Mueller <dave@perljedi.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by Dave Mueller.
+This software is Copyright (c) 2015 by Liquid Web Inc.
 
 This is free software, licensed under:
 
@@ -106,6 +121,8 @@ L<Net::Kubernetes|Net::Kubernetes>
 
 =item * L<Net::Kubernetes::Role::APIAccess>
 
+=item * L<Net::Kubernetes::Role::ResourceCatalog>
+
 =item * L<Net::Kubernetes::Role::ResourceCreator>
 
 =item * L<Net::Kubernetes::Role::ResourceFactory>
