@@ -1,6 +1,6 @@
 package Net::Kubernetes::Resource::Node;
 # ABSTRACT: Object representatioon of a Kubernetes Pod
-$Net::Kubernetes::Resource::Node::VERSION = '1.03';
+$Net::Kubernetes::Resource::Node::VERSION = '1.04';
 use Moose;
 use URI;
 extends 'Net::Kubernetes::Resource';
@@ -17,7 +17,7 @@ sub get_pods {
     }else{
         $selector->{'spec.host'} = $self->metadata->{name};
     }
-    $uri->query_form(fieldSelector=>$self->_build_selector_from_hash($selector));
+    $uri->query_form(fieldSelector=>$self->build_selector_from_hash($selector));
     print "Query with $uri\n";
     my $res = $self->ua->request($self->create_request(GET => $uri));
     if ($res->is_success) {
@@ -39,15 +39,6 @@ sub get_pods {
     }
 }
 
-sub _build_selector_from_hash {
-	my($self, $select_hash) = @_;
-	my(@selectors);
-	foreach my $label (keys %{ $select_hash }){
-		push @selectors, $label.'='.$select_hash->{$label};
-	}
-	return join(",", @selectors);
-}
-
 return 42;
 
 __END__
@@ -62,7 +53,7 @@ Net::Kubernetes::Resource::Node - Object representatioon of a Kubernetes Pod
 
 =head1 VERSION
 
-version 1.03
+version 1.04
 
 =head1 AUTHOR
 
@@ -70,7 +61,7 @@ Dave Mueller <dave@perljedi.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by Dave Mueller.
+This software is Copyright (c) 2015 by Liquid Web Inc.
 
 This is free software, licensed under:
 
