@@ -1,6 +1,6 @@
 package Net::Kubernetes::Resource::ReplicationController;
 # ABSTRACT: Object representatioon of a Kubernetes Replication Controller
-$Net::Kubernetes::Resource::ReplicationController::VERSION = '1.03';
+$Net::Kubernetes::Resource::ReplicationController::VERSION = '1.04';
 use Moose;
 use URI;
 use Time::HiRes;
@@ -15,11 +15,11 @@ with 'Net::Kubernetes::Resource::Role::HasPods';
 
 sub scale {
     my($self, $replicas, $timeout) = @_;
-    $timeout ||= 5;
+    $timeout //= $self->scale_timeout;
     $self->spec->{replicas} = $replicas;
     $self->update;
     my $st = time;
-    while((time - $st) < $timeout){
+    while($timeout < 0 || (time - $st) < $timeout){
         my $pods = $self->get_pods;
         if(scalar(@$pods) == $replicas){
             return "scaled";
@@ -43,7 +43,7 @@ Net::Kubernetes::Resource::ReplicationController - Object representatioon of a K
 
 =head1 VERSION
 
-version 1.03
+version 1.04
 
 =head1 METHODS
 
@@ -51,13 +51,27 @@ version 1.03
 
 Fetch a list off all pods belonging to this replication controller.
 
+=head2 $rc->scale($replicas[, $timeout]);
+
+Scales the replication controller to the requested number of replicas. This
+method will poll waiting for the replicas to reach the requested value for the
+duration specified by $timeout in seconds. 
+
+On success, the string "scaled" is returned. 
+On a timeout, 0 is returned.
+
+If $timeout is -1, then the method will wait indefinitely.
+
+A default scale timeout can be specified by passing scale_timeout
+to the constructor.
+
 =head1 AUTHOR
 
 Dave Mueller <dave@perljedi.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by Dave Mueller.
+This software is Copyright (c) 2015 by Liquid Web Inc.
 
 This is free software, licensed under:
 
@@ -87,6 +101,8 @@ L<Net::Kubernetes|Net::Kubernetes>
 
 =item * L<Net::Kubernetes::Role::APIAccess>
 
+=item * L<Net::Kubernetes::Role::ResourceCatalog>
+
 =back
 
 =cut
