@@ -1,27 +1,35 @@
 package Net::Kubernetes::Resource::Role::HasPods;
 # ABSTRACT: Resource role for types that may contain pods
-$Net::Kubernetes::Resource::Role::HasPods::VERSION = '1.03';
+$Net::Kubernetes::Resource::Role::HasPods::VERSION = '1.04';
 use Moose::Role;
 
 with 'Net::Kubernetes::Role::APIAccess';
+with 'Net::Kubernetes::Role::ResourceCatalog';
+
+requires 'namespace';
 
 
 sub get_pods {
 	my($self) = @_;
-	my $uri = URI->new_abs("../pods", $self->path);
-	$uri->query_form(labelSelector=>$self->_build_selector_from_hash($self->spec->{selector}));
+	my $uri = URI->new($self->get_resource_path('Pod'));
+	$uri->query_form(labelSelector=>$self->build_selector_from_hash($self->spec->{selector}));
 	my $res = $self->ua->request($self->create_request(GET => $uri));
 	if ($res->is_success) {
 		my $pod_list = $self->json->decode($res->content);
 		my(@pods)=();
 		foreach my $pod (@{ $pod_list->{items}}){
-			$pod->{apiVersion} = $pod_list->{apiVersion};
-			my(%create_args) = %$pod;
-			$create_args{api_version} = $pod->{apiVersion};
-			$create_args{username} = $self->username if($self->username);
-			$create_args{password} = $self->password if($self->password);
-			$create_args{url} = $self->url;
-			$create_args{base_path} = $pod->{metadata}{selfLink};
+			$pod->{apiVersion}           = $pod_list->{apiVersion};
+			my(%create_args)             = %$pod;
+			$create_args{api_version}    = $pod->{apiVersion};
+			$create_args{server_version} = $self->server_version;
+			$create_args{namespace}      = $self->namespace;
+			$create_args{username}       = $self->username if($self->username);
+			$create_args{password}       = $self->password if($self->password);
+			$create_args{url}            = $self->url;
+			$create_args{base_path}      = $pod->{metadata}{selfLink};
+			$create_args{ssl_cert_file}  = $self->ssl_cert_file if($self->ssl_cert_file);
+			$create_args{ssl_key_file}   = $self->ssl_key_file if($self->ssl_key_file);
+			$create_args{ssl_ca_file}    = $self->ssl_ca_file if($self->ssl_ca_file);
 			push @pods, Net::Kubernetes::Resource::Pod->new(%create_args);
 		}
 		return wantarray ? @pods : \@pods;
@@ -30,15 +38,6 @@ sub get_pods {
 	}
 }
 
-sub _build_selector_from_hash {
-	my($self, $select_hash) = @_;
-	my(@selectors);
-	foreach my $label (keys %{ $select_hash }){
-		push @selectors, $label.'='.$select_hash->{$label};
-	}
-	return join(",", @selectors);
-}
-
 return 42;
 
 __END__
@@ -53,7 +52,7 @@ Net::Kubernetes::Resource::Role::HasPods - Resource role for types that may cont
 
 =head1 VERSION
 
-version 1.03
+version 1.04
 
 =head1 METHODS
 
@@ -67,7 +66,7 @@ Dave Mueller <dave@perljedi.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by Dave Mueller.
+This software is Copyright (c) 2015 by Liquid Web Inc.
 
 This is free software, licensed under:
 
@@ -91,6 +90,8 @@ L<Net::Kubernetes|Net::Kubernetes>
 
 =item * L<Net::Kubernetes::Role::APIAccess>
 
+=item * L<Net::Kubernetes::Role::ResourceCatalog>
+
 =back
 
 =cut
