@@ -1,6 +1,6 @@
 package Net::Kubernetes::Role::APIAccess;
 # ABSTRACT: Role allowing direct access to the REST api
-$Net::Kubernetes::Role::APIAccess::VERSION = '1.03';
+$Net::Kubernetes::Role::APIAccess::VERSION = '1.04';
 use Moose::Role;
 require LWP::UserAgent;
 require HTTP::Request;
@@ -8,6 +8,7 @@ use JSON::MaybeXS;
 require Cpanel::JSON::XS;
 require URI;
 use MIME::Base64;
+use syntax "try";
 
 
 has url => (
@@ -23,6 +24,14 @@ has api_version => (
 	required => 1,
 );
 
+has server_version => (
+	is       => 'ro',
+	isa      => 'Str',
+	required => 1,
+	lazy     => 1,
+	builder  => '_build_server_version',
+);
+
 has base_path => (
 	is       => 'ro',
 	isa      => 'Str',
@@ -48,7 +57,7 @@ has ua => (
 	isa      => 'LWP::UserAgent',
 	required => 1,
 	builder  => '_build_lwp_agent',
-    lazy     => 1,
+	lazy     => 1,
 );
 
 has token => (
@@ -58,35 +67,42 @@ has token => (
 );
 
 has 'json' => (
-    is       => 'ro',
-    isa      => JSON::MaybeXS::JSON,
-    required => 1,
-    lazy     => 1,
-    builder  => '_build_json',
+	is       => 'ro',
+	isa      => JSON::MaybeXS::JSON,
+	required => 1,
+	lazy     => 1,
+	builder  => '_build_json',
 );
 
 has 'ssl_cert_file' => (
-    is       => 'rw',
-    isa      => 'Str',
-    required => 0,
+	is       => 'rw',
+	isa      => 'Str',
+	required => 0,
 );
 
 has 'ssl_key_file' => (
-    is       => 'rw',
-    isa      => 'Str',
-    required => 0,
+	is       => 'rw',
+	isa      => 'Str',
+	required => 0,
 );
 
 has 'ssl_ca_file' => (
-    is       => 'rw',
-    isa      => 'Str',
-    required => 0,
+	is       => 'rw',
+	isa      => 'Str',
+	required => 0,
 );
 
 has 'ssl_verify' => (
-    is       => 'rw',
-    isa      => 'Str',
-    required => 0,
+	is       => 'rw',
+	isa      => 'Str',
+	required => 0,
+);
+
+has 'scale_timeout' => (
+	is       => 'rw',
+	isa      => 'Num',
+	required => 0,
+	default  => 5,
 );
 
 around BUILDARGS => sub {
@@ -121,7 +137,8 @@ around BUILDARGS => sub {
 
 sub _create_default_base_path {
 	my($self) = @_;
-	return '/api/'.$self->api_version;
+	
+	return '/api/' . $self->api_version;
 }
 
 sub path {
@@ -129,22 +146,49 @@ sub path {
 	return $self->url.$self->base_path;
 }
 
+sub _build_server_version {
+	my $self = shift;
+
+	my($version_info) = $self->send_request($self->create_request(GET => $self->url . '/version'));
+	return "$version_info->{major}.$version_info->{minor}";
+
+}
+
 sub _build_lwp_agent {
 	my $self = shift;
 	my $ua = LWP::UserAgent->new(agent=>'net-kubernetes-perl/0.20');
-    if($self->ssl_cert_file){
-        $ua = LWP::UserAgent->new(ssl_opts => {
-            verify_hostname => $self->ssl_verify,
-            SSL_cert_file => $self->ssl_cert_file,
-            SSL_key_file  => $self->ssl_key_file,
-            SSL_ca_file   => $self->ssl_ca_file,
-        });
-    }
+	if($self->ssl_cert_file){
+		$ua = LWP::UserAgent->new(ssl_opts => {
+			verify_hostname => $self->ssl_verify,
+			SSL_cert_file => $self->ssl_cert_file,
+			SSL_key_file  => $self->ssl_key_file,
+			SSL_ca_file   => $self->ssl_ca_file,
+		});
+	}
 	return $ua;
 }
 
+sub send_request {
+	my ($self, $req) = @_;
+	my ($res) = $self->ua->request($req);
+
+	unless ($res->is_success) {
+		my $message;
+		try{
+			my $obj = $self->json->decode($res->content);
+			$message = $obj->{message};
+		}
+		catch($e) {
+			$message = $res->message;
+		}
+		Net::Kubernetes::Exception->throw(code=>$res->code, message=>$message);
+	}
+
+	return $self->json->decode($res->content);
+}
+
 sub _build_json {
-    return JSON::MaybeXS->new->allow_blessed(1)->convert_blessed(1);
+	return JSON::MaybeXS->new->allow_blessed(1)->convert_blessed(1);
 }
 
 sub create_request {
@@ -159,6 +203,47 @@ sub create_request {
 	return $req;
 }
 
+sub build_selector_from_hash {
+	my($self, $select_hash) = @_;
+	my(@selectors);
+
+	my %labels;
+	my @expressions;
+	if (ref($select_hash->{matchLabels}) || ref($select_hash->{matchExpressions})) {
+		if ($select_hash->{matchLabels}) {
+			%labels = %{$select_hash->{matchLabels}};
+		}
+
+		if ($select_hash->{matchExpressions}) {
+			@expressions = @{$select_hash->{matchExpressions}};
+		}
+	}
+	else {
+		%labels = %$select_hash;
+	}
+
+	foreach my $label (keys %labels){
+		push @selectors, $label . '=' . $labels{$label};
+	}
+	foreach my $expression (@expressions) {
+		my $operator = lc($expression->{operator});
+		my $selector;
+		if ($operator eq 'exists') {
+			$selector = $expression->{key};
+		}
+		elsif ($operator eq 'doesnotexist') {
+			$selector = "!$expression->{key}";
+		}
+		else {
+			$selector = "$expression->{key} $operator (" . join(',', @{$expression->{values}}) . ")";
+		}
+
+		push @selectors, $selector;
+	}
+
+	return join(",", @selectors);
+}
+
 
 return 42;
 
@@ -174,7 +259,7 @@ Net::Kubernetes::Role::APIAccess - Role allowing direct access to the REST api
 
 =head1 VERSION
 
-version 1.03
+version 1.04
 
 =head1 AUTHOR
 
@@ -182,7 +267,7 @@ Dave Mueller <dave@perljedi.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by Dave Mueller.
+This software is Copyright (c) 2015 by Liquid Web Inc.
 
 This is free software, licensed under:
 
