@@ -1,11 +1,12 @@
 package Net::Kubernetes::Role::ResourceCreator;
 # ABSTRACT: Role to allow creation of resources from either objects or files.
-$Net::Kubernetes::Role::ResourceCreator::VERSION = '1.03';
+$Net::Kubernetes::Role::ResourceCreator::VERSION = '1.04';
 use Moose::Role;
 use MooseX::Aliases;
 require YAML::XS;
 require Net::Kubernetes::Resource::Service;
 require Net::Kubernetes::Resource::Pod;
+require Net::Kubernetes::Resource::Deployment;
 require Net::Kubernetes::Resource::ReplicationController;
 require Net::Kubernetes::Resource::Secret;
 require Net::Kubernetes::Exception;
@@ -18,6 +19,7 @@ with 'Net::Kubernetes::Role::ResourceFactory';
 requires 'ua';
 requires 'create_request';
 requires 'json';
+requires 'namespace';
 
 
 sub create_from_file {
@@ -52,7 +54,29 @@ sub create {
 	my $validBooleanProperties = qr/readOnly(?:RootFilesystem)?|hostNetwork|hostPID|hostIPC|stdin(?:Once)?|tty|runAsNonRoot|privileged|ready|unschedulable/;
 	$content =~ s/((["'])(?:$validBooleanProperties)\2:\s)(["'])(true|false)\3/$1$4/g;
 	# /EndHack
-    my $req = $self->create_request(POST=>$self->path.'/'.lc($object->{kind}).'s', undef, $content);
+
+	# It looks like some objects have particular versioning and special paths.
+	# Kubernetes is already training its users to provide apiVersion in the yaml
+	# on a per resource level, so asking for the apiVersion per object seems 
+	# reasonable.
+	my $resource_path = $self->url;
+	if (my $version = $object->{apiVersion}) {
+		if ($version =~ /\//) {
+			$resource_path .= "/apis/$version";
+		}
+		else {
+			$resource_path .= "/api/$version";
+		}
+
+		$resource_path .= "/namespaces/" . $self->namespace;
+	}
+	else {
+		$resource_path = $self->path;
+	}
+
+	$resource_path .= '/' . lc($object->{kind}) . 's';
+
+	my $req = $self->create_request(POST => $resource_path, undef, $content);
 	my $res = $self->ua->request($req);
 	if ($res->is_success) {
 		return $self->create_resource_object($self->json->decode($res->content));
@@ -83,7 +107,7 @@ Net::Kubernetes::Role::ResourceCreator - Role to allow creation of resources fro
 
 =head1 VERSION
 
-version 1.03
+version 1.04
 
 =head1 METHODS
 
@@ -104,7 +128,7 @@ Dave Mueller <dave@perljedi.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by Dave Mueller.
+This software is Copyright (c) 2015 by Liquid Web Inc.
 
 This is free software, licensed under:
 
@@ -126,6 +150,8 @@ L<Net::Kubernetes|Net::Kubernetes>
 
 =over 4
 
+=item * L<Net::Kubernetes::Role::ResourceCatalog>
+
 =item * L<Net::Kubernetes::Role::ResourceFactory>
 
 =back
