@@ -1,6 +1,6 @@
 package Net::Kubernetes::Role::ResourceFactory;
 # ABSTRACT: Role to allow easy construction of Net::Kubernetes::Resouce::* objects
-$Net::Kubernetes::Role::ResourceFactory::VERSION = '1.03';
+$Net::Kubernetes::Role::ResourceFactory::VERSION = '1.04';
 use Moose::Role;
 use MooseX::Aliases;
 require Net::Kubernetes::Resource::Endpoint;
@@ -11,6 +11,10 @@ require Net::Kubernetes::Resource::ReplicationController;
 require Net::Kubernetes::Resource::Secret;
 require Net::Kubernetes::Resource::Service;
 require Net::Kubernetes::Resource::ServiceAccount;
+require Net::Kubernetes::Resource::Deployment;
+require Net::Kubernetes::Resource::ReplicaSet;
+
+with 'Net::Kubernetes::Role::ResourceCatalog';
 
 sub create_resource_object {
 	my($self, $object, $kind) = @_;
@@ -18,6 +22,12 @@ sub create_resource_object {
 	$object->{kind} ||= $kind;
 	my(%create_args) = %$object;
 	$create_args{api_version} = $object->{apiVersion};
+	$create_args{server_version} = $self->server_version;
+	
+	unless ($self->is_global_resource($kind)) {
+		$create_args{namespace} = $object->{namespace} || $self->namespace;
+	}
+
 	$create_args{username} = $self->username if($self->username);
 	$create_args{password} = $self->password if($self->password);
 	$create_args{url} = $self->url;
@@ -44,7 +54,7 @@ Net::Kubernetes::Role::ResourceFactory - Role to allow easy construction of Net:
 
 =head1 VERSION
 
-version 1.03
+version 1.04
 
 =head1 AUTHOR
 
@@ -52,7 +62,7 @@ Dave Mueller <dave@perljedi.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by Dave Mueller.
+This software is Copyright (c) 2015 by Liquid Web Inc.
 
 This is free software, licensed under:
 
@@ -70,4 +80,12 @@ L<Net::Kubernetes|Net::Kubernetes>
 
 =back
 
+=head1 CONSUMES
+
+=over 4
+
+=item * L<Net::Kubernetes::Role::ResourceCatalog>
+
+=back
+
 =cut
