@@ -1,6 +1,6 @@
 package Net::Kubernetes::Role::ResourceFetcher;
-# ABSTRACT: Role to give access to list_* methods.
-$Net::Kubernetes::Role::ResourceFetcher::VERSION = '1.03';
+# ABSTRACT: Role to give access to get_* methods.
+$Net::Kubernetes::Role::ResourceFetcher::VERSION = '1.04';
 use Moose::Role;
 use MooseX::Aliases;
 use syntax "try";
@@ -9,10 +9,12 @@ require Net::Kubernetes::Resource::Pod;
 require Net::Kubernetes::Resource::ReplicationController;
 
 with 'Net::Kubernetes::Role::ResourceFactory';
+with 'Net::Kubernetes::Role::ResourceCatalog';
 
 sub get_resource_by_name {
 	my($self, $name, $type) = @_;
-	my($res) = $self->ua->request($self->create_request(GET => $self->path.'/'.$type.'/'.$name));
+	my $resource_path = $self->get_resource_path(lc($type));
+	my($res) = $self->ua->request($self->create_request(GET => "$resource_path/$name"));
 	if ($res->is_success) {
 		return $self->create_resource_object($self->json->decode($res->content));
 	}
@@ -39,11 +41,11 @@ __END__
 
 =head1 NAME
 
-Net::Kubernetes::Role::ResourceFetcher - Role to give access to list_* methods.
+Net::Kubernetes::Role::ResourceFetcher - Role to give access to get_* methods.
 
 =head1 VERSION
 
-version 1.03
+version 1.04
 
 =head1 AUTHOR
 
@@ -51,7 +53,7 @@ Dave Mueller <dave@perljedi.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by Dave Mueller.
+This software is Copyright (c) 2015 by Liquid Web Inc.
 
 This is free software, licensed under:
 
@@ -73,6 +75,8 @@ L<Net::Kubernetes|Net::Kubernetes>
 
 =over 4
 
+=item * L<Net::Kubernetes::Role::ResourceCatalog>
+
 =item * L<Net::Kubernetes::Role::ResourceFactory>
 
 =back
